package config

import (
	log "github.com/sirupsen/logrus"
	"os"
	"path/filepath"

	"gopkg.in/ini.v1"
)

type Config struct {
	cfg *ini.File
}

var gConfig = &Config{}

func init() {
	confpath := "app.conf"
	cfg, err := ini.Load(confpath)
	if err != nil {
		log.Println("文件读取错误", err)
		os.Exit(1)
	}
	gConfig.cfg = cfg
}

func GetConfig() *Config {
	return gConfig
}

func (c *Config) ServerAddr() string {
	addr := c.cfg.Section("server").Key("address").MustString("0.0.0.0:9900")
	return addr
}

func (c *Config) PrivateKey() string {
	priv := c.cfg.Section("server").Key("privatekey").String()
	return priv
}

func (c *Config) LogLevel() string {
	level := c.cfg.Section("log").Key("level").String()
	if len(level) == 0 {
		return "info"
	}
	return level
}

func (c *Config) LogFile() string {
	name := c.cfg.Section("log").Key("file").String()
	if len(name) == 0 {
		name = "service.log"
	}
	filename := filepath.Join("logs", name)
	return filename
}
