package main

import (
	"github.com/gin-gonic/gin"
	log "github.com/sirupsen/logrus"
	"gitlab.com/hashrs/randomservice/config"
	"gitlab.com/hashrs/randomservice/router"
	"io"
	"net/http"
	"os"
	"os/signal"
	"syscall"
)

func InitLog(conf *config.Config) {
	level := conf.LogLevel()
	switch level {
	case "info":
		log.SetLevel(log.InfoLevel)
	case "debug":
		log.SetLevel(log.DebugLevel)
	default:
		log.SetLevel(log.InfoLevel)
	}
	logfile, err := os.OpenFile(conf.LogFile(), os.O_CREATE|os.O_APPEND|os.O_WRONLY, os.ModeAppend|0755)
	//logfile, err := os.OpenFile(conf.LogFile(), os.O_WRONLY|os.O_CREATE, 0755)
	if err != nil {
		log.Error("can't open log file", conf.LogFile())
	}
	Formatter := new(log.TextFormatter)
	Formatter.TimestampFormat = "2006-01-02T15:04:05.999999999Z07:00"
	Formatter.FullTimestamp = true
	Formatter.ForceColors = true
	log.SetFormatter(Formatter)

	log.SetOutput(io.MultiWriter(logfile))
}

func Cors() gin.HandlerFunc {
	return func(c *gin.Context) {
		method := c.Request.Method
		origin := c.Request.Header.Get("Origin")
		if origin != "" {
			c.Header("Access-Control-Allow-Origin", "*")
			c.Header("Access-Control-Allow-Methods", "POST, GET, OPTIONS, PUT, DELETE")
			c.Header("Access-Control-Allow-Headers", "Content-Type,AccessToken,X-CSRF-Token, Authorization")
			c.Header("Access-Control-Allow-Credentials", "true")
			c.Set("content-type", "application/json")
		}
		//放行所有OPTIONS方法
		if method == "OPTIONS" {
			c.AbortWithStatus(http.StatusNoContent)
		}
		c.Next()
	}
}


func main() {
	conf := config.GetConfig()
	InitLog(conf)

	go func() {
		r := gin.New()
		//r.Use(Cors()) //默认跨域
		r.Use(gin.Recovery())
		router.InitRouter(r)

		log.Infof("Start HTTP Server on %s:%d", conf.ServerAddr())
		if err := r.Run(conf.ServerAddr()); err != nil {
			log.WithError(err).Fatalln("fail to run server")
		}
	}()

	exitSig := []os.Signal{os.Interrupt, syscall.SIGTERM}
	exitCh := make(chan os.Signal, 2)
	signal.Notify(exitCh, exitSig...)

	<-exitCh

	os.Exit(1)
}
