package service

import (
	"crypto/rand"
	"encoding/hex"
	"errors"
	"fmt"
	"gitlab.com/hashrs/randomservice/common"
)

func RandomService(account []byte, pk string) (map[string]interface{}, error) {
	r, err := rand.Prime(rand.Reader, 128)
	if err != nil {
		return nil, errors.New("generate prime failed")
	}
	data := common.BytesCombine(account, r.Bytes())
	sig, err := common.Sign(pk, data)
	if err != nil {
		return nil, errors.New(fmt.Sprintf("sign failed (%s)", err))
	}

	var res = make(map[string]interface{})
	res["rand"] = r.Text(16)
	res["signature"] = "0x" + hex.EncodeToString(sig)

	return res, nil
}
